sync_accessibility_tree

Function sync_accessibility_tree 

pub fn sync_accessibility_tree(
    state: &mut NativeAccessibilityState,
    accessibility_configs: &FxHashMap<u32, AccessibilityConfig>,
    accessibility_bounds: &FxHashMap<u32, BoundingBox>,
    accessibility_element_order: &[u32],
    focused_element_id: u32,
    viewport: Dimensions,
) -> Vec<PendingA11yAction>
Synchronise Ply’s accessibility state with the platform screen reader.

This is the native equivalent of accessibility_web::sync_accessibility_tree. It is called from Ply::eval() on every frame when the a11y feature is enabled and we are not compiling for WASM.

Returns a list of actions requested by the screen reader (focus changes, clicks) that the engine should process.