Module elements

Module elements 

Structs

BorderBuilder
Builder for configuring border properties using a closure.
FloatingBuilder
Builder for configuring floating element properties using a closure.
OverflowBuilder
Builder for configuring overflow (clip/scroll) properties using a closure.
ShapeRotationBuilder
Builder for configuring shape rotation (vertex-level).
VisualRotationBuilder
Builder for configuring visual rotation (render-target based).

Enums

FloatingAttachToElement
Defines how a floating element is attached to other elements.
FloatingClipToElement
Defines how a floating element is clipped.
PointerCaptureMode
Specifies how pointer capture should behave for floating elements.