#[non_exhaustive]pub enum ImageFormat {
Show 15 variants
Png,
Jpeg,
Gif,
WebP,
Pnm,
Tiff,
Tga,
Dds,
Bmp,
Ico,
Hdr,
OpenExr,
Farbfeld,
Avif,
Qoi,
}Expand description
An enumeration of supported image formats. Not all formats support both encoding and decoding.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Png
An Image in PNG Format
Jpeg
An Image in JPEG Format
Gif
An Image in GIF Format
WebP
An Image in WEBP Format
Pnm
An Image in general PNM Format
Tiff
An Image in TIFF Format
Tga
An Image in TGA Format
Dds
An Image in DDS Format
Bmp
An Image in BMP Format
Ico
An Image in ICO Format
Hdr
An Image in Radiance HDR Format
OpenExr
An Image in OpenEXR Format
Farbfeld
An Image in farbfeld Format
Avif
An Image in AVIF format.
Qoi
An Image in QOI format.
Implementations
Sourceimpl ImageFormat
impl ImageFormat
Sourcepub fn from_extension<S>(ext: S) -> Option<ImageFormat>
pub fn from_extension<S>(ext: S) -> Option<ImageFormat>
Return the image format specified by a path’s file extension.
Example
use image::ImageFormat;
let format = ImageFormat::from_extension("jpg");
assert_eq!(format, Some(ImageFormat::Jpeg));Sourcepub fn from_path<P>(path: P) -> Result<ImageFormat, ImageError>
pub fn from_path<P>(path: P) -> Result<ImageFormat, ImageError>
Return the image format specified by the path’s file extension.
Example
use image::ImageFormat;
let format = ImageFormat::from_path("images/ferris.png")?;
assert_eq!(format, ImageFormat::Png);
Sourcepub fn from_mime_type<M>(mime_type: M) -> Option<ImageFormat>
pub fn from_mime_type<M>(mime_type: M) -> Option<ImageFormat>
Return the image format specified by a MIME type.
Example
use image::ImageFormat;
let format = ImageFormat::from_mime_type("image/png").unwrap();
assert_eq!(format, ImageFormat::Png);Sourcepub fn to_mime_type(&self) -> &'static str
pub fn to_mime_type(&self) -> &'static str
Return the MIME type for this image format or “application/octet-stream” if no MIME type exists for the format.
Some notes on a few of the MIME types:
- The portable anymap format has a separate MIME type for the pixmap, graymap and bitmap formats, but this method returns the general “image/x-portable-anymap” MIME type.
- The Targa format has two common MIME types, “image/x-targa” and “image/x-tga”; this method returns “image/x-targa” for that format.
- The QOI MIME type is still a work in progress. This method returns “image/x-qoi” for that format.
Example
use image::ImageFormat;
let mime_type = ImageFormat::Png.to_mime_type();
assert_eq!(mime_type, "image/png");Sourcepub fn extensions_str(self) -> &'static [&'static str]
pub fn extensions_str(self) -> &'static [&'static str]
Return a list of applicable extensions for this format.
All currently recognized image formats specify at least on extension but for future compatibility you should not rely on this fact. The list may be empty if the format has no recognized file representation, for example in case it is used as a purely transient memory format.
The method name extensions remains reserved for introducing another method in the future
that yields a slice of OsStr which is blocked by several features of const evaluation.
Sourcepub fn reading_enabled(&self) -> bool
pub fn reading_enabled(&self) -> bool
Return the ImageFormats which are enabled for reading.
Sourcepub fn writing_enabled(&self) -> bool
pub fn writing_enabled(&self) -> bool
Return the ImageFormats which are enabled for writing.
Sourcepub fn all() -> impl Iterator<Item = ImageFormat>
pub fn all() -> impl Iterator<Item = ImageFormat>
Return all ImageFormats