load_string

Function load_string 

pub async fn load_string(path: &str) -> Result<String, Error>
Load string from the path and block until its loaded. Right now this will use load_file and from_utf8_lossy internally, but implementation details may change in the future