#[repr(C, align(1))]pub struct BVec2 {
pub x: bool,
pub y: bool,
}Expand description
A 2-dimensional bool vector mask.
Fields
x: booly: boolImplementations
Sourceimpl BVec2
impl BVec2
Sourcepub const fn from_array(a: [bool; 2]) -> BVec2
pub const fn from_array(a: [bool; 2]) -> BVec2
Creates a new vector mask from a bool array.
Sourcepub fn bitmask(self) -> u32
pub fn bitmask(self) -> u32
Returns a bitmask with the lowest 2 bits set from the elements of self.
A true element results in a 1 bit and a false element in a 0 bit. Element x goes
into the first lowest bit, element y into the second, etc.