Camera3D

Struct Camera3D 

pub struct Camera3D {
    pub position: Vec3,
    pub target: Vec3,
    pub up: Vec3,
    pub fovy: f32,
    pub aspect: Option<f32>,
    pub projection: Projection,
    pub render_target: Option<RenderTarget>,
    pub viewport: Option<(i32, i32, i32, i32)>,
    pub z_near: f32,
    pub z_far: f32,
}

Fields

position: Vec3

Camera position.

target: Vec3

Camera target it looks-at.

up: Vec3

Camera up vector (rotation over its axis).

fovy: f32

Camera field-of-view aperture in Y (radians) in perspective, used as near plane width in orthographic.

aspect: Option<f32>

Screen aspect ratio.

By default aspect is calculated with screen_width() / screen_height() on each frame.

projection: Projection

Camera projection type, perspective or orthographics.

render_target: Option<RenderTarget>

If “render_target” is set - camera will render to texture.

Otherwise to the screen.

viewport: Option<(i32, i32, i32, i32)>

Part of the screen to render to.

None means the whole screen.

Viewport do not affect camera space, just the render position on the screen.

Useful for things like splitscreen.

z_near: f32

Camera near plane

z_far: f32

Camera far plane