pub struct RenderTargetParams {
pub sample_count: i32,
pub depth: bool,
}Fields
sample_count: i321 means no multi sampling. Note that sample_count > 1 is not supported on GL2, GLES2 and WebGL1
depth: booldepth: true creates a depth render target attachment and allows such a render target being used for a depth-testing cameras