Vertex

Struct Vertex 

#[repr(C)]
pub struct Vertex { pub position: Vec3, pub uv: Vec2, pub color: [u8; 4], pub normal: Vec4, }

Fields

position: Vec3uv: Vec2color: [u8; 4]normal: Vec4

Normal is not used by macroquad and is completely optional. Might be usefull for custom shaders. While normal is not used by macroquad, it is completely safe to use it to pass arbitary user data, hence Vec4.

Implementations

Source

impl Vertex

pub fn new(x: f32, y: f32, z: f32, u: f32, v: f32, color: Color) -> Vertex

pub fn new2(position: Vec3, uv: Vec2, color: Color) -> Vertex