pub enum GraphicAsset {
Path(&'static str),
Bytes {
file_name: &'static str,
data: &'static [u8],
},
}Expand description
Represents an asset that can be loaded as a texture. This can be either a file path or embedded bytes.
Variants
Implementations