Structs
- Border
Builder - Builder for configuring border properties using a closure.
- Floating
Builder - Builder for configuring floating element properties using a closure.
- Overflow
Builder - Builder for configuring overflow (clip/scroll) properties using a closure.
- Shape
Rotation Builder - Builder for configuring shape rotation (vertex-level).
- Visual
Rotation Builder - Builder for configuring visual rotation (render-target based).
Enums
- Floating
Attach ToElement - Defines how a floating element is attached to other elements.
- Floating
Clip ToElement - Defines how a floating element is clipped.
- Pointer
Capture Mode - Specifies how pointer capture should behave for floating elements.