pub struct FloatingBuilder { /* private fields */ }Expand description
Builder for configuring floating element properties using a closure.
Implementations
Sourceimpl FloatingBuilder
impl FloatingBuilder
Sourcepub fn anchor(
&mut self,
element: (AlignX, AlignY),
parent: (AlignX, AlignY),
) -> &mut Self
pub fn anchor( &mut self, element: (AlignX, AlignY), parent: (AlignX, AlignY), ) -> &mut Self
Sets the attachment points of the floating element and its parent.
Each tuple is (AlignX, AlignY) — the first for the element, the second for the parent.
ⓘ
.floating(|f| f.anchor((CenterX, Bottom), (CenterX, Top)))Sourcepub fn attach_parent(&mut self) -> &mut Self
pub fn attach_parent(&mut self) -> &mut Self
Attaches this floating element to its parent element (default behavior).
Sourcepub fn attach_root(&mut self) -> &mut Self
pub fn attach_root(&mut self) -> &mut Self
Attaches this floating element to the root of the layout.
Sourcepub fn attach_id(&mut self, id: impl Into<Id>) -> &mut Self
pub fn attach_id(&mut self, id: impl Into<Id>) -> &mut Self
Attaches this floating element to a specific element by ID.
Sourcepub fn clip_by_parent(&mut self) -> &mut Self
pub fn clip_by_parent(&mut self) -> &mut Self
Clips this floating element to its parent’s bounds.
Sourcepub fn passthrough(&mut self) -> &mut Self
pub fn passthrough(&mut self) -> &mut Self
Sets pointer capture mode to Passthrough.