pub struct Camera2D {
pub rotation: f32,
pub zoom: Vec2,
pub target: Vec2,
pub offset: Vec2,
pub render_target: Option<RenderTarget>,
pub viewport: Option<(i32, i32, i32, i32)>,
}Fields
rotation: f32Rotation in degrees.
zoom: Vec2Scaling, should be (1.0, 1.0) by default.
target: Vec2Rotation and zoom origin.
offset: Vec2Displacement from target.
render_target: Option<RenderTarget>If “render_target” is set - camera will render to texture.
Otherwise to the screen.
viewport: Option<(i32, i32, i32, i32)>Part of the screen to render to.
None means the whole screen.
Viewport do not affect camera space, just the render position on the screen.
Useful for things like splitscreen.
Implementations
Sourceimpl Camera2D
impl Camera2D
Sourcepub fn from_display_rect(rect: Rect) -> Camera2D
pub fn from_display_rect(rect: Rect) -> Camera2D
Will make camera space equals given rect.
Sourceimpl Camera2D
impl Camera2D
Sourcepub fn world_to_screen(&self, point: Vec2) -> Vec2
pub fn world_to_screen(&self, point: Vec2) -> Vec2
Returns the screen space position for a 2d camera world space position.
Screen position in window space - from (0, 0) to (screen_width, screen_height()). When a viewport is set, returns coordinates within that viewport’s screen region.
Sourcepub fn screen_to_world(&self, point: Vec2) -> Vec2
pub fn screen_to_world(&self, point: Vec2) -> Vec2
Returns the world space position for a 2d camera screen space position.
Point is a screen space position, often mouse x and y.