Image

Struct Image 

pub struct Image {
    pub bytes: Vec<u8>,
    pub width: u16,
    pub height: u16,
}
Image, data stored in CPU memory

Fields

bytes: Vec<u8>width: u16height: u16

Implementations

Source

impl Image

pub const fn empty() -> Image

Creates an empty Image.

let image = Image::empty();
pub fn from_file_with_format( bytes: &[u8], format: Option<ImageFormat>, ) -> Result<Image, Error>

Creates an Image from a slice of bytes that contains an encoded image.

If format is None, it will make an educated guess on the ImageFormat.

Example
let icon = Image::from_file_with_format(
    include_bytes!("../examples/rust.png"),
    Some(ImageFormat::Png),
    );
pub fn gen_image_color(width: u16, height: u16, color: Color) -> Image

Creates an Image filled with the provided Color.

pub fn update(&mut self, colors: &[Color])

Updates this image from a slice of Colors.

pub const fn width(&self) -> usize

Returns the width of this image.

pub const fn height(&self) -> usize

Returns the height of this image.

pub fn get_image_data(&self) -> &[[u8; 4]]

Returns this image’s data as a slice of 4-byte arrays.

pub fn get_image_data_mut(&mut self) -> &mut [[u8; 4]]

Returns this image’s data as a mutable slice of 4-byte arrays.

pub fn set_pixel(&mut self, x: u32, y: u32, color: Color)

Modifies a pixel Color in this image.

pub fn get_pixel(&self, x: u32, y: u32) -> Color

Returns a pixel Color from this image.

pub fn sub_image(&self, rect: Rect) -> Image

Returns an Image from a rect inside this image.

pub fn blend(&mut self, other: &Image)

Blends this image with another image (of identical dimensions) Inspired by OpenCV saturated blending

pub fn overlay(&mut self, other: &Image)

Overlays an image on top of this one. Slightly different from blending two images, overlaying a completely transparent image has no effect on the original image, though blending them would.

pub fn export_png(&self, path: &str)

Saves this image as a PNG file. This method is not supported on web and will panic.