Rect

Struct Rect 

pub struct Rect {
    pub x: f32,
    pub y: f32,
    pub w: f32,
    pub h: f32,
}
A 2D rectangle, defined by its top-left corner, width and height.

Fields

x: f32

The x-coordinate of the top-left corner.

y: f32

The y-coordinate of the top-left corner.

w: f32

The width of the Rect, going to the right.

h: f32

The height of the Rect, going down.

Implementations

Source

impl Rect

pub const fn new(x: f32, y: f32, w: f32, h: f32) -> Rect

Creates a new rectangle from its top-left corner, width and height.

Arguments:
  • x - x-coordinate of the top-left corner.
  • y - y-coordinate of the top-left corner.
  • w - width of the Rect, going to the right.
  • h - height of the Rect, going down.
pub const fn point(&self) -> Vec2

Returns the top-left corner of the Rect.

pub const fn size(&self) -> Vec2

Returns the size (width and height) of the Rect.

pub const fn center(&self) -> Vec2

Returns the center position of the Rect.

pub const fn left(&self) -> f32

Returns the left edge of the Rect.

pub const fn right(&self) -> f32

Returns the right edge of the Rect.

pub const fn top(&self) -> f32

Returns the top edge of the Rect.

pub const fn bottom(&self) -> f32

Returns the bottom edge of the Rect.

pub const fn move_to(&mut self, destination: Vec2)

Moves the Rect’s origin to (x, y).

pub const fn scale(&mut self, sx: f32, sy: f32)

Scales the Rect by a factor of (sx, sy), growing towards the bottom-left.

pub const fn contains(&self, point: Vec2) -> bool

Checks whether the Rect contains a Point.

pub const fn overlaps(&self, other: &Rect) -> bool

Checks whether the Rect overlaps another Rect.

pub const fn combine_with(self, other: Rect) -> Rect

Returns a new Rect that includes all points of these two Rects.

pub const fn intersect(&self, other: Rect) -> Option<Rect>

Returns an intersection rect if there is any intersection.

pub const fn offset(self, offset: Vec2) -> Rect

Translate rect origin by offset vector.

pub fn normalized(&self) -> Rect

Returns a normalized rect where width and height are guaranteed to be positive.