FileTypeHandler

Type Alias FileTypeHandler 

pub type FileTypeHandler = Box<dyn Fn(&Path, &Path) -> Vec<String>>;
A custom file-type handler callback.

Receives the path to the source file and the output directory. Must compile/write output files itself. Returns a list of glob patterns for dependency files — if any matched file changes, this shader will be recompiled even if the main source hasn’t changed.

Aliased Type

pub struct FileTypeHandler(/* private fields */);